package dom.xpath;

import java.io.IOException;
import java.util.List;

import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.Namespace;
import org.jdom2.filter.ElementFilter;
import org.jdom2.input.SAXBuilder;
import org.jdom2.xpath.XPathExpression;
import org.jdom2.xpath.XPathFactory;

/** 
 * Checking external images accessibility 
 */
public class CheckExtImage {
   private final SAXBuilder builder = new SAXBuilder();

   /** 
    * Read an XHTML document and search for images. The image filenames will be
    * written to standard out.
    * @param xhtmlFilename The XHTML's filename to be examined.
    * @throws JDOMException General parsing fault
    * @throws IOException  file access problem
    */
   public void process(final String xhtmlFilename) throws JDOMException, IOException {

      final Document htmlInput = builder.build(xhtmlFilename);  
      
      final Namespace htmlNamespace = // This will allow for XPath expressions like xhtml:img
            Namespace.getNamespace("xhtml", "http://www.w3.org/1999/xhtml");
      
      final XPathExpression<Element> xpath = XPathFactory.instance().compile (
            "//xhtml:img[starts-with(@src, 'http://') or starts-with(@src, 'https://') or starts-with(@src, 'ftp://')]",
            new ElementFilter(), null, htmlNamespace);
      
      final List<Element> images = xpath.evaluate (htmlInput);

      for (final Element image: images) {
         CheckUrl.checkReadability(image.getAttributeValue("src"));
      }
   }
}